Crate beetry_message

Crate beetry_message 

Message typing primitives for Beetry.

This crate is an internal Beetry implementation crate and is not considered part of the public API. For public APIs, use the beetry crate.

Re-exports

pub use type_hash;

Structs

MessageHash
Describes the hash of the message type (and not concrete message type instance).
MessageSpec

Traits

Message
Trait for types that should be considered as a message type.